Module alloc

Module alloc 

Re-export the allocator2 API for use.

Modules

alloc
Memory allocation APIs
boxed
The Box<T> type for heap allocation.
collections
vec
A contiguous growable array type with heap-allocated contents, written Vec<T>.

Macros

unsize_box
Allows turning a Box<T: Sized, A> into a Box<U: ?Sized, A> where T can be unsizing-coerced into a U.
vec
Creates a Vec containing the arguments.

Structs

AllocError
The AllocError error indicates an allocation failure that may be due to resource exhaustion or to something wrong when combining the given input arguments with this allocator.
Global
The global memory allocator.
Layout
Layout of a block of memory.
LayoutError
The LayoutError is returned when the parameters given to Layout::from_size_align or some other Layout constructor do not satisfy its documented constraints.
System
The default memory allocator provided by the operating system.

Traits

Allocator
An implementation of Allocator can allocate, grow, shrink, and deallocate arbitrary blocks of data described via Layout.
GlobalAlloc
A memory allocator that can be registered as the standard library’s default through the #[global_allocator] attribute.
SliceExt
Slice methods that use Box and Vec from this crate.

Functions

alloc
Allocates memory with the global allocator.
alloc_zeroed
Allocates zero-initialized memory with the global allocator.
dealloc
Deallocates memory with the global allocator.
handle_alloc_error
Signals a memory allocation error.
realloc
Reallocates memory with the global allocator.