pub struct Reader<R: Read>(pub R);Tuple Fields
0: RTrait Implementations
Sourceimpl<R: Read> Decoder for Reader<R>
impl<R: Read> Decoder for Reader<R>
Sourcefn decode_byte(&mut self) -> Result<u8, DecodeError>
fn decode_byte(&mut self) -> Result<u8, DecodeError>
Decodes a single byte from the reader.
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), DecodeError>
Sourcefn decode_ranged<T: Decode + PartialOrd>(
&mut self,
range: impl RangeBounds<T>,
) -> Result<T, DecodeError>
fn decode_ranged<T: Decode + PartialOrd>( &mut self, range: impl RangeBounds<T>, ) -> Result<T, DecodeError>
Decodes a value and ensures it falls within the supplied range.
Sourcefn assert_magic(&mut self) -> Result<(), DecodeError>
fn assert_magic(&mut self) -> Result<(), DecodeError>
Verifies that the next bytes in the stream match the magic sequence.
Sourcefn decode<T: Decode>(&mut self) -> Result<T, DecodeError>
fn decode<T: Decode>(&mut self) -> Result<T, DecodeError>
Decodes a value implementing the
Decode trait.Sourcefn decode_trailing<T: Decode>(&mut self) -> Result<Option<T>, DecodeError>
fn decode_trailing<T: Decode>(&mut self) -> Result<Option<T>, DecodeError>