Module v1

Module v1 

Types and helpers for the version 1 serialization format. Components for the version 1 OpenTimestamps serialization format.

Modules

opcode
OpenTimestamps OpCodes

Structs

BitcoinAttestation
DetachedTimestamp
A file containing a timestamp for another file Contains a timestamp, along with a header and the digest of the file.
DigestHeader
Header describing the digest that anchors a timestamp.
EASAttestation
Attestation by EAS::attest using schema 0x5c5b8b295ff43c8e442be11d569e94a4cd5476f5e23df0f71bdd408df6b9649c.
EASTimestamped
Attestation by EAS::timestamp
FinalizationError
Error indicating that finalization of a timestamp failed due to conflicting inputs.
PendingAttestation
RawAttestation
Raw Proof that some data existed at a given time.
Step
An execution Step.
TimestampBuilder

Enums

Timestamp
Proof that that one or more attestations commit to a message.

Traits

Attestation
ConsistentWith
Trait for objects that can be checked for consistency with another object.
MayHaveInput
Trait for objects that may have input data.

Type Aliases

AttestationTag
Tag identifying the attestation kind.