Timestamp

Enum Timestamp 

pub enum Timestamp<A: Allocator = Global> {
    Step(Step<A>),
    Attestation(RawAttestation<A>),
}
Proof that that one or more attestations commit to a message.

This should not be confused with DetachedTimestamp, single Timestamps DO NOT include the digest of the message they commit to.

Sample Timestamp:

execute APPEND 7d9472db4ae254e8
execute SHA256
execute APPEND 65191d41c625e4505a442928ec4211b3
execute SHA256
execute APPEND 000639ee5837a935dce596c85f1ce323d5219afe84ee0832ee6614924f4c6598
execute SHA256
execute PREPEND 6944db61
execute APPEND 0ef41e45bb5534b3
result attested by Pending: update URI https://alice.btc.calendar.opentimestamps.org

Variants



Step(Step<A>)



Attestation(RawAttestation<A>)

Implementations

Source

impl Timestamp

pub fn builder() -> TimestampBuilder<Global>

Creates a new timestamp builder.

pub fn merge(timestamps: Vec<Timestamp, Global>) -> Timestamp

Merges multiple timestamps into a single FORK timestamp.

Panics

This will panic if there are conflicting inputs when finalizing unfinalized timestamps.

pub fn try_merge( timestamps: Vec<Timestamp, Global>, ) -> Result<Timestamp, FinalizationError>

Try to merge multiple timestamps into a single FORK timestamp.

Returns an error if there are conflicting inputs when finalizing unfinalized timestamps.

Source

impl<A: Allocator> Timestamp<A>

pub fn op(&self) -> OpCode

Returns the opcode of this timestamp node.

pub fn as_step(&self) -> Option<&Step<A>>

Returns this timestamp as a step, if it is one.

pub fn as_attestation(&self) -> Option<&RawAttestation<A>>

Returns this timestamp as an attestation, if it is one.

pub fn allocator(&self) -> &A

Returns the allocator used by this timestamp node.

pub fn is_finalized(&self) -> bool

Returns true if this timestamp is finalized.

pub fn attestations(&self) -> AttestationIter<'_, A>

Iterates over all attestations in this timestamp.

pub fn pending_attestations_mut(&mut self) -> PendingAttestationIterMut<'_, A>

Iterates over all pending attestation steps in this timestamp.

Note

This iterator will yield Timestamp instead of RawAttestation.

Source

impl<A: Allocator + Clone> Timestamp<A>

pub fn builder_in(alloc: A) -> TimestampBuilder<A>

Creates a new timestamp builder with the given allocator.

pub fn finalize(&self, input: &[u8])

Finalizes the timestamp with the given input data.

Panics

Panics if the timestamp is already finalized with different input data.

pub fn try_finalize(&self, input: &[u8]) -> Result<(), FinalizationError>

Try finalizes the timestamp with the given input data.

Returns an error if the timestamp is already finalized with different input data.

pub fn merge_in(timestamps: Vec<Timestamp<A>, A>, alloc: A) -> Timestamp<A>

Merges multiple timestamps into a single FORK timestamp.

Panics

This will panic if there are conflicting inputs when finalizing unfinalized timestamps.

pub fn try_merge_in( timestamps: Vec<Timestamp<A>, A>, alloc: A, ) -> Result<Timestamp<A>, FinalizationError>

Merges multiple timestamps into a single FORK timestamp.

This will attempt to finalize unfinalized timestamps if any of the input timestamps are finalized.

Returns an error if there are conflicting inputs when finalizing unfinalized timestamps.