Module opcode

Module opcode 

OpenTimestamps OpCodes

It contains opcode information and utilities to work with opcodes.

Structs

DigestOp
An OpenTimestamps digest opcode.
OpCode
An OpenTimestamps opcode.
OpCodeFromStrError
Error returned when parsing an invalid opcode from a string.

Constants

APPEND
The 0xf0 (“APPEND”) opcode.
ATTESTATION
The 0x00 (“ATTESTATION”) opcode.
FORK
The 0xff (“FORK”) opcode.
HEXLIFY
The 0xf3 (“HEXLIFY”) opcode.
KECCAK256
The 0x67 (“KECCAK256”) opcode.
PREPEND
The 0xf1 (“PREPEND”) opcode.
REVERSE
The 0xf2 (“REVERSE”) opcode.
RIPEMD160
The 0x03 (“RIPEMD160”) opcode.
SHA1
The 0x02 (“SHA1”) opcode.
SHA256
The 0x08 (“SHA256”) opcode.

Traits

DigestOpExt
Extension trait for Digest implementors to get the corresponding DigestOp.