TimestampBuilder

Struct TimestampBuilder 

pub struct TimestampBuilder<A: Allocator = Global> { /* private fields */ }

Implementations

Source

impl<A: Allocator + Clone> TimestampBuilder<A>

pub fn sha1(&mut self) -> &mut Self

Push the SHA1 opcode.

Source

impl<A: Allocator + Clone> TimestampBuilder<A>

pub fn ripemd160(&mut self) -> &mut Self

Push the RIPEMD160 opcode.

Source

impl<A: Allocator + Clone> TimestampBuilder<A>

pub fn sha256(&mut self) -> &mut Self

Push the SHA256 opcode.

Source

impl<A: Allocator + Clone> TimestampBuilder<A>

pub fn keccak256(&mut self) -> &mut Self

Push the KECCAK256 opcode.

Source

impl<A: Allocator + Clone> TimestampBuilder<A>

pub fn reverse(&mut self) -> &mut Self

Push the REVERSE opcode.

Source

impl<A: Allocator + Clone> TimestampBuilder<A>

pub fn hexlify(&mut self) -> &mut Self

Push the HEXLIFY opcode.

Source

impl<A: Allocator + Clone> TimestampBuilder<A>

pub fn append(&mut self, data: Vec<u8, A>) -> &mut Self

Push the APPEND opcode.

Source

impl<A: Allocator + Clone> TimestampBuilder<A>

pub fn prepend(&mut self, data: Vec<u8, A>) -> &mut Self

Push the PREPEND opcode.

Source

impl<A: Allocator + Clone> TimestampBuilder<A>

pub fn new_in(alloc: A) -> TimestampBuilder<A>

Creates a new TimestampBuilder.

pub fn push_step(&mut self, op: OpCode) -> &mut Self

Pushes a new execution step without immediate data to the timestamp.

Panics

Panics if:

  • the opcode is control opcode
  • the opcode is an opcode with immediate data
pub fn digest<D: DigestOpExt>(&mut self) -> &mut Self

Pushes a new digest step to the timestamp.

pub fn merkle_proof<D: DigestOpExt>( &mut self, proof: SiblingIter<'_, D>, ) -> &mut Self

Pushes the steps corresponding to the given Merkle proof to the timestamp.

pub fn commitment(&self, input: impl AsRef<[u8]>) -> Vec<u8, A>

Computes the commitment of the timestamp for the given input.

In this context, the commitment is the deterministic result of executing the timestamp’s linear chain of operations over the input bytes. It is computed by:

  1. Taking the provided input bytes as the initial value.
  2. Iterating over all steps in the order they were added to the builder.
  3. For each step, applying its opcode to the current value together with the step’s immediate data via OpCode::execute_in, and using the result as the new current value.

The final value after all steps have been applied is returned as the commitment.

pub fn attest<'a, T: Attestation<'a>>( self, attestation: T, ) -> Result<Timestamp<A>, EncodeError>

Finalizes the timestamp with the given attestation.

Notes

The built timestamp does not include any input data. The input data must be provided later using the finalize method on the Timestamp object.

pub fn concat(self, timestamp: Timestamp<A>) -> Timestamp<A>

Append the given timestamp after the steps in the builder.