Encoding and decoding support for OpenTimestamps proofs.
Modules
- v1
- Types and helpers for the version 1 serialization format. Components for the version 1 OpenTimestamps serialization format.
Structs
- Reader
- Versioned
Proof - Wrapper that prefixes a proof with its version and magic bytes.
- Writer
Constants
- MAGIC
- Magic bytes that every proof must start with.
Traits
- Decode
- Deserializes a value from an OpenTimestamps-compatible byte stream.
- Decode
In - Deserializes a value from an OpenTimestamps-compatible byte stream.
- Decoder
- Helper trait for reading OpenTimestamps primitives from a byte stream.
- Encode
- Serializes a value into an OpenTimestamps-compatible byte stream.
- Encoder
- Helper trait for writing OpenTimestamps primitives to a byte stream.
- Proof
- Trait implemented by proof payloads for a specific serialization version.
Type Aliases
- Version
- Version number of the serialization format.