Types and helpers for the version 1 serialization format. Components for the version 1 OpenTimestamps serialization format.
Modules
- opcode
- OpenTimestamps OpCodes
Structs
- Bitcoin
Attestation - Detached
Timestamp - A file containing a timestamp for another file Contains a timestamp, along with a header and the digest of the file.
- Digest
Header - Header describing the digest that anchors a timestamp.
- EASAttestation
- Attestation by
EAS::attestusing schema0x5c5b8b295ff43c8e442be11d569e94a4cd5476f5e23df0f71bdd408df6b9649c. - EASTimestamped
- Attestation by
EAS::timestamp - Finalization
Error - Error indicating that finalization of a timestamp failed due to conflicting inputs.
- Pending
Attestation - RawAttestation
- Raw Proof that some data existed at a given time.
- Step
- An execution Step.
- Timestamp
Builder
Enums
- Timestamp
- Proof that that one or more attestations commit to a message.
Traits
- Attestation
- Consistent
With - Trait for objects that can be checked for consistency with another object.
- MayHave
Input - Trait for objects that may have input data.
Type Aliases
- Attestation
Tag - Tag identifying the attestation kind.