pub trait ConsistentWith<T: ToInput + ?Sized>: MayHaveInput {
// Provided methods
fn is_consistent_with(&self, other: &T) -> bool { ... }
fn is_consistent_with_strict(&self, other: &T) -> bool { ... }
}Expand description
Trait for objects that can be checked for consistency with another object.
Provided Methods
Sourcefn is_consistent_with(&self, other: &T) -> bool
fn is_consistent_with(&self, other: &T) -> bool
Checks if self is consistent with the given input.
Note: Returns true if any of the inputs is not set.
Sourcefn is_consistent_with_strict(&self, other: &T) -> bool
fn is_consistent_with_strict(&self, other: &T) -> bool
Checks if self is consistent with the given input.
Note: Returns false if xor of the inputs is not set.